@charset "utf-8";

/*
 Hive Appier Framework
 Copyright (c) 2008-2016 Hive Solutions Lda.

 This file is part of Hive Appier Framework.

 Hive Appier Framework is free software: you can redistribute it and/or modify
 it under the terms of the Apache License as published by the Apache
 Foundation, either version 2.0 of the License, or (at your option) any
 later version.

 Hive Appier Framework is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 Apache License for more details.

 You should have received a copy of the Apache License along with
 Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.
*/

/*
 __author__    = João Magalhães <joamag@hive.pt>
 __version__   = 1.0.0
 __revision__  = $LastChangedRevision$
 __date__      = $LastChangedDate$
 __copyright__ = Copyright (c) 2008-2016 Hive Solutions Lda.
 __license__   = Apache License, Version 2.0
*/

.panel-model {
    border: 1px solid #e0e0e0;
    margin: 24px 0px 24px 0px;
    padding: 0px 0px 0px 0px;
    width: 690px;
}

.panel-model h3 {
    background-color: #f0f0f0;
    border-bottom: 1px solid #e0e0e0;
    font-size: 14px;
    margin: 0px 0px 0px 0px;
    padding: 14px 16px 14px 16px;
    text-transform: uppercase;
}

.panel-model ul {
    margin: 0px 0px 0px 0px;
}

.panel-model ul li {
    margin: 0px 0px 0px 0px;
    padding: 12px 16px 12px 16px;
    text-transform: capitalize;
}

.panel-model ul li:hover {
    background-color: inherit;
}

.panel-model ul li .button {
    font-size: 13px;
}

.panel-model ul li .left {
    float: left;
}

.panel-model ul li .right {
    float: right;
}

.pages {
    font-size: 0px;
    font-weight: bold;
    padding: 32px 0px 32px 0px;
    text-align: center;
}

.pages > .page {
    border-bottom: 1px solid #cccccc;
    border-left: 1px solid #cccccc;
    border-top: 1px solid #cccccc;
    display: inline-block;
    font-size: 14px;
    margin: 0px 0px 0px 0px;
    padding: 4px 10px 4px 10px;
}

.pages > .page:first-child {
    border-radius: 4px 0px 0px 4px;
    -moz-border-radius: 4px 0px 0px 4px;
    -webkit-border-radius: 4px 0px 0px 4px;
}

.pages > .page:last-child {
    border-radius: 0px 4px 4px 0px;
    -moz-border-radius: 0px 4px 4px 0px;
    -webkit-border-radius: 0px 4px 4px 0px;
    border-right: 1px solid #cccccc;
}

.pages > .page:hover {
    background-color: #f2f2f2;
}

.pages > .page.selected {
    background-color: #888888;
    border-color: #888888;
    color: #ffffff;
}

.pages > .page.disabled {
    color: #aaaaaa;
}

.pages > .page.disabled:hover {
    background-color: #ffffff;
}

.pages > a.page {
    color: #4d4d4d;
}

.header-message .message-contents {
    background-color: #cee6c5;
    border: 1px solid #86c795;
    color: #4d4d4d;
    cursor: pointer;
    font-weight: bold;
    height: 30px;
    line-height: 30px;
    margin: -17px auto -15px auto;
    text-align: center;
    width: 300px;
}

.header-message.error .message-contents {
    background-color: #fcc0c0;
    border-color: #f68f8f;
}
